! ===========================================================================
! Tidsformer
! Utkar tidsformer och perspektivsbyten i Inform med svensk versttning.
! Skrivet av Tomas berg 2008-10-05
! Version 1.2
!
! ===========================================================================
!
! Instruktioner:
!
! * Tidsformsbyte() med antingen parametern "presens" eller "imperfekt" --
! fr beskrivning av nutid respektive dtid.
!
! * Perspektivsbyte() med parameter 1,2, eller 3, fr berttarperspektiv.
! Anvnder man sig av den tredje formen kan man vlja att lgga till
! ett namn. Gr man inte detta kommer spelarnamnet skrivas ut som
! han/hon/den/det istllet. Om man ska byta till en namnls spelarkaraktr
! r det lmpligast att gra detta innan funktionen Perspektivsbyte() --
! d denna funktion kollar av genus p player-objektet och skriver in
! lmpligt pronomen istllet fr namnet i huvudrollsvariablen.

! Man har ven som val att skriva in ytterligare ett namn i tredjepersons-
! perspektivet, detta d det finns undantag med vissa namn nr det
! gller stor begynnelsebokstav. Sg att spelets huvudkaraktr r ett djur
! till exempel, d kan man gra fljande:
! Perspektivsbyte(3,"Tigern","tigern");

! * AnvandSpelarPronomen(true/false) -- r en funktion man kan anvnda
! sig av om man vill skifta frn just ett "namn" till "han/hon/den/det".
! Denna skiftning gller endast tredjepersonsperspektivet.

! Ytterligare ngra funktioner fr utskrifter (med exempel givna i frsta,
! andra och tredjepersonsperspektiv):
!
! CJagEllerDu(player)               -- Jag, Du, Pelle eller Tigern
! JagEllerDu(player)                  -- jag, du, Pelle eller tigern
! MigEllerDig(player)               -- mig, dig, sig
! CMinEllerDin(player)                -- Min, Din, Sin
! MinEllerDin(player)               -- min, din, sin
!
! Efter rutinen AnvandSpelarPronomen(true); skulle samma utskrifter ge:
!
! CJagEllerDu(player)               -- Jag, Du, Han eller Den
! JagEllerDu(player)                  -- jag, du, han eller den
! MigEllerDig(player)               -- mig, dig, sig
! CMinEllerDin(player)                -- Min, Din, Hans eller Dess
! MinEllerDin(player)               -- min, din, hans eller dess
!
! OBS: Ovanstende utskrifter frutstter att player-objektet har korrekt
! attribut. I tigerns fall skulle detta attribut vara "uter" och i Pelles
! fall "male".


System_file;

Constant  presens   = 0;
Constant  imperfekt = 1;
Global    Tidsform = presens;
Global    spelar_pronomen = false;
Global    Huvudroll = "du";
Global    Perspektiv = 2;


[NewCantGoRoutine;
  #Ifdef STRIKT_PRESENS;    Tidsform = presens;   #Endif;
  #Ifdef STRIKT_IMPERFEKT;  Tidsform = imperfekt; #Endif;

  CJagEllerDu(player);
    switch(Tidsform)
    {
      presens:    print " kan ";
      imperfekt:  print " kunde ";
    }
    "inte g drt.";
  ];


[Tidsformsbyte x;
    Tidsform = x;

    !Uppdatera "cant_go"-rutinen s att det inte str "Du kan inte g drt":
    !(Samma uppdatering sker om man anvnder Perspektivsbyte ocks)
    ChangeDefault(cant_go, NewCantGoRoutine);

    switch(x)
    {
      presens:
        IS__TX       = " r";
        ARE__TX      = " r";
        IS2__TX      = "r ";
        ARE2__TX     = "r ";
        return;

      imperfekt:
        IS__TX       = " var";
        ARE__TX      = " var";
        IS2__TX      = "var ";
        ARE2__TX     = "var ";
        return;
    }
  ];


[Perspektivsbyte view text ltext;       ! ltext should be lower case version of text
  if(text == nothing)
  {
    !Anonym spelarkaraktr, anvnd bara han, hon, den eller det...
    AnvandSpelarPronomen(true);

    if (player has pluralname)  Huvudroll =  "de";
    else if (player has uter)   Huvudroll = "den";
    else if (player has neuter)   Huvudroll = "det";
    else if (player has female)   Huvudroll = "hon";
    else Huvudroll = "han";
  }

    if(ltext == nothing) ltext = text;    ! If no ltext is provided use the same as text
    if(ltext)
      Huvudroll = ltext;
    else if(text)
      Huvudroll = text;
    Perspektiv = view;

    ChangeDefault(cant_go, NewCantGoRoutine);

    switch(Perspektiv)
    {
      1:  !Frstaperson
          FORMER__TX    = "mitt tidigare jag";
          YOURSELF__TX  = "mig sjlv";
          YOU__TX       = "Jag";
          LYOU__TX       = "jag";
          if (player provides short_name)
            player.short_name = YOURSELF__TX;

      2:  !Andraperson
          FORMER__TX    = "ditt tidigare jag";
          YOURSELF__TX  = "dig sjlv";
          YOU__TX       = "Du";
          LYOU__TX       = "du";
          if (player provides short_name)
            player.short_name = YOURSELF__TX;

      3:  !Tredjeperson
          FORMER__TX    = "sitt tidigare jag";
          YOURSELF__TX  = "sig sjlv";
          YOU__TX       = text;
          LYOU__TX       = ltext;
          if (player provides short_name)
            player.short_name = YOURSELF__TX;
    }

  ];


[ AnvandSpelarPronomen x;
    spelar_pronomen = x;
];


[ JagEllerDu x;   ! Used in the nominative
  x=x; ! Fr att slippa kompilatorvarning
  switch(Perspektiv)
  {
    1:  print "jag";
    2:  print "du";
    3:
      if(spelar_pronomen == false) { print (string) Huvudroll; return; }
      SetGender(actor);
      if (actor has pluralname) { print "de"; return; }
      if (actor has uter)         { print "den"; return; }
      if (actor has neuter)       { print "det"; return; }
      if (actor has female)       { print "hon"; return; }
      print "han";
  }
  ];

[CJagEllerDu obj;
  PrintToBuffer(StorageForShortName, 160, JagEllerDu, obj);
  StorageForShortName->WORDSIZE =
    UpperCase(StorageForShortName->WORDSIZE);
  PrintBuffer(StorageForShortName);
  ];

[MigEllerDig x;
  x=x; ! Fr att slippa kompilatorvarning
  switch(Perspektiv)
  {
    1:  print "mig";
    2:  print "dig";
    3:  print "sig";
  }
  rtrue;
  ];

[MinEllerDin obj gender;
  ! Antingen r gender satt, eller ocks ska det lsas frn obj
  if(gender==0) {
    SetGender(obj);
    if (obj has pluralname) gender=pluralname;
    else if (obj has neuter) gender=neuter;
    else if (obj has uter) gender=uter;
    else if (obj has female) gender=female;
    else gender=male;
  }
  switch(Perspektiv) {
    1:  switch(gender) {
          pluralname: print "mina";
          neuter: print "mitt";
          default: print "min";
        }
    2:  switch(gender) {
          pluralname: print "dina";
          neuter: print "ditt";
          default: print "din";
        }
    3:  SetGender(actor);
        if (actor has pluralname) { print "deras"; return; }
        if (actor has neuter or uter) { print "dess"; return; }
        if (actor has female) {print "hennes"; return; }
        print "hans";
  }
  ];

[MinEllerDinGenus gender;
  MinEllerDin(0, gender);
  ];

[CMinEllerDin obj gender;
  PrintToBuffer(StorageForShortName, 160, MinEllerDin, obj, gender);
  StorageForShortName->WORDSIZE =
    UpperCase(StorageForShortName->WORDSIZE);
  PrintBuffer(StorageForShortName);
  ];

[CMinEllerDinGenus gender;
  CMinEllerDin(0, gender);
  ];


Object tidsformer_meddelanden LibraryExtensions
  with ext_messages [;
        #Ifdef STRIKT_PRESENS;    return PresentMsg(lm_n, lm_o);   #Endif;
        #Ifdef STRIKT_IMPERFEKT;  return PastMsg(lm_n, lm_o);      #Endif;

        #Ifndef STRIKT_IMPERFEKT;
        #Ifndef STRIKT_PRESENS;
        if(Tidsform==imperfekt)
          return PastMsg(lm_n, lm_o);
        else
          return PresentMsg(lm_n, lm_o);
        #Endif;
        #Endif;
      ];

#Ifndef STRIKT_IMPERFEKT;

[ PresentMsg n x1;
  Prompt:  print "^>";
  Answer, Ask:    "", (cJagEllerDu) player, " fr inget svar.";
  Attack:         "Vld r knappast lsningen hr.";
  Blow:           "Det vore meningslst att blsa p ", (DenEllerHonom) x1, ".";
  Burn:           "Det vore farligt och fga produktivt.";
  Buy:            "Det finns just inget att kpa.";
  Climb:          "Det verkar inte s konstruktivt.";
  Close:   switch(n)
           {   1: print_ret (CDenEllerHan) x1," r inte ngot ",(JagEllerDu) player," kan stnga.";
               2: print_ret (CDenEllerHan) x1,
                  " r redan ",(indefadjclosed) x1,".";
               3: "",(cJagEllerDu) player, " stnger ", (the) x1, ".";
           }
  CommandsOff,
  CommandsOn,
  CommandsRead:   rfalse;
  Consult:        "",(cJagEllerDu) player," upptcker inget intressant i ", (the) x1, ".";
  Cut:            print "Att skra i ";
                  if(x1 == player) print "sig sjlv";
                  else print(the) x1;
                  " verkar inte srskilt konstruktivt.";
  Dig:            "Det kan inte ge s mycket att grva hr.";
  Disrobe: switch(n)
           {   1: print_ret (CDenEllerHonom) x1, " har ", (JagEllerDu) player, " inte p ",(MigEllerDig) player,".";
               2: "",(cJagEllerDu) player," tar av ", (the) x1, ".";
           }
  Drink:          "Det finns inget vrt att dricka hr.";
  Drop:    switch(n)
           {   1: print_ret (CDenEllerHan) x1, " r redan hr.";
               2: "",(cJagEllerDu) player," har inte ", (DenEllerHonom) x1, ".";
               3: "(",(cJagEllerDu) player ," tar frst av ", (the) x1, ")";
               4: "Slppt.";
           }
  Eat:     switch(n)
           {   1: print (CDenEllerHan) x1," r helt enkelt otlig";
                  if(x1 has pluralname) "a.";
                  if(x1 has neuter) "t."; else ".";
               2: "",(cJagEllerDu) player," ter ", (the) x1, ". Inte illa.";
           }
  EmptyT:  switch(n)
           {   1: print_ret (The) x1, " kan inte innehlla saker.";
               2: print_ret (The) x1, " r ",(indefadjclosed) x1,".";
               3: print_ret (The) x1, " r redan ",(indefadjempty) x1,".";
               4: "Det skulle just inte tmma ngonting alls.";
           }
  Enter:   switch(n)
           {   1: print "Men ",(JagEllerDu) player," r ju redan ";
                  if (x1 has supporter) print "p "; else print "i ";
                  print_ret (the) x1, ".";
               2: print (CDenEllerHan) x1, " r inte till fr "; ! # Should be more varied.
                  switch (verb_word) {
                      'st','stll': "att st p.";
                      'sitt': "att sitta p.";
                      'ligg': "att ligga p.";
                      default: "det.";
                  }
               3: print_ret (The) x1, " r ",(indefadjclosed) x1,", s det blir nog svrt.";

               4: "Frst mste ",(JagEllerDu) player," st p ",(MinEllerDinGenus) pluralname," egna ftter igen.";

               5: switch (verb_word)
                  {
                      'st','stll':
                        print (cJagEllerDu) player," stller ",(MigEllerDig) player;
                      'sitt','stt':
                        print (cJagEllerDu) player," stter ",(MigEllerDig) player;
                      'ligg','lgg':
                        print (cJagEllerDu) player," lgger ",(MigEllerDig) player;
                      default:
                        print (cJagEllerDu) player," kliver "; if(x1 has supporter) print "upp"; else print "in";
                  }
                  if (x1 has supporter) print " p "; else print " i ";
                  print_ret (the) x1, ".";
               6: "(",(cJagEllerDu) player," lmnar ",(the) x1, ")";
               7: if (x1 has supporter) "(kliver p ", (the) x1, ")^";
                  if (x1 has container) "(kliver in i ", (the) x1, ")^";
                  "(gr p ", (the) x1, ")^";
           }
  Examine: switch(n)
           {   1: "Mrker, substantiv. En frnvaro av ljus att se i.";
               2: "",(cJagEllerDu) player," ser inget speciellt med ", (the) x1, ".";
               3: print (The) x1, " r just nu ";
                  if (x1 has on) "p."; else "av.";
           }
  Exit:    switch(n)
           {   1: "Men ",(JagEllerDu) player," r ju inte i ngot fr tillfllet.";
               2: "Det kan bli svrt, efterom ", (the) x1, " r ",(indefadjclosed) x1,".";
               3: "",(cJagEllerDu) player," lmnar ",(the) x1, ".";
               4: print "Men ",(JagEllerDu) player," r inte ";
                  if (x1 has supporter) print "p "; else print "i ";
                  print_ret (the) x1, ".";
           }
  Fill:           "Men det finns inget vatten hr att fylla p.";
  FullScore: switch(n)
           {   1: if (deadflag) print "",(cJagEllerDu) player," fick ";
                  else          print "",(cJagEllerDu) player," har ";
                  "pong, frdelat enligt fljande:^";
               2: "hitta viktiga freml";
               3: "beska viktiga platser";
               4: print "totalt (av ", MAX_SCORE; ")";
           }
  GetOff:         "Men ",(JagEllerDu) player," r ju inte p ", (the) x1, " fr tillfllet.";
  Give:    switch(n)
           {   1: "",(cJagEllerDu) player," hller inte i ", (the) x1, ".";
               2: "",(cJagEllerDu) player," bollar lite med ", (the) x1,
                  ", men det ger inte s mycket.";
               3: print_ret (The) x1, " verkar inte bry sig om ",(MinEllerDinGenus) neuter," erbjudande.";
           }
  Go:      switch(n)
           {   1: print "Frst mste ",(JagEllerDu) player," kliva ";
                  if (x1 has supporter) print "av "; else print "ur ";
                  print_ret (the) x1, ".";
               2: print_ret (string) CANTGO__TX;
                  ! "You can't go that way."
               3: "",(cJagEllerDu) player," kan inte klttra upp p ", (the) x1, ".";
               4: "",(cJagEllerDu) player," kan inte klttra ner p ", (the) x1, ".";
               5: "Det blir svrt, eftersom ", (the) x1, " r i vgen.";
               6: "Det kan ",(JagEllerDu) player," inte, eftersom ", (the) x1," inte leder ngonstans.";
           }
  Insert:  switch(n)
           {   1: "",(cJagEllerDu) player," mste hlla i ", (the) x1,
                  " innan ",(DenEllerHan) player," kan lgga ", (DenEllerHonom) x1,
                  " i ngot annat.";
               2: print_ret (CDenEllerHan) x1, " kan inte innehlla saker.";
               3: print_ret (The) x1, " r ",(indefadjclosed) x1,".";
               4: "Frst mste ",(JagEllerDu) player," ta av ", (DenEllerHonom) x1, ".";
               5: "",(cJagEllerDu) player," kan inte lgga ngot i sig sjlvt.";
               6: "(",(cJagEllerDu) player, " tar frst av ", (DenEllerHonom) x1, ")^";
               7: "Det finns inte plats fr ngot mer i ", (the) x1, ".";
               8: "Gjort.";
               9: "",(cJagEllerDu) player," placerar ", (the) x1, " i ", (the) second, ".";
           }
  Inv:     switch(n)
           {   1: "",(cJagEllerDu) player," har ingenting.";
               2: print (cJagEllerDu) player," har";
               3: print ":^";
               4: print ".^";
           }
  Jump:           "",(cJagEllerDu) player," hoppar p stllet. Det ger inget.";
  JumpOver, Tie:  "Det skulle inte vara till ngon strre hjlp.";
  Kiss:           "Tnk lite mer p spelet istllet.";
  Listen:         "",(cJagEllerDu) player," hr inget ovntat.";
  ListMiscellany:
           switch(n)
           {   1: print " (lyser)";
               2: print " (",(indefadjclosed) x1,")";
               3: print " (som r ",(indefadjclosed) x1," och lyser)";
               4: print " (",(indefadjempty) x1,")";
               5: print " (som r ",(indefadjempty) x1," och lyser)";
               6: print " (som r ",(indefadjclosed) x1," och ",(indefadjempty) x1,")";
               7: print " (som r ",(indefadjclosed) x1,", ",(indefadjempty) x1," och lyser)";
               8: print " (som lyser och r ",(indefadjworn) x1;
               9: print " (lyser";
              10: print " (",(indefadjworn) x1;
              11: print " (som ";
              12: print "r ", (indefadjopen) x1;
              13: print "r ", (indefadjopen) x1," men ",(indefadjempty) x1;
              14: print "r ", (indefadjclosed) x1;
              15: print "r ", (indefadjclosed) x1," och ",(indefadjlocked) x1;
              16: print " och ",(indefadjempty) x1;
              17: print " (som r ",(indefadjempty) x1,")";
              18: print " innehllande ";
              19: print " (p ";
              20: print ", ovanp ";
              21: print " (i ";
              22: print ", inuti ";
           }
  LMode1,
  LMode2,
  LMode3:   rfalse;
  Lock:    switch(n)
           {   1: print_ret (CDenEllerHan) x1, " verkar inte vara ngot ",(JagEllerDu) player," kan lsa.";
               2: print_ret (CDenEllerHan) x1, " r redan ",(indefadjlocked) x1,".";
               3: "Frst mste ",(JagEllerDu) player," stnga ", (the) x1, ".";
               4: print_ret (CDenEllerHan) x1, " verkar inte passa lset.";
               5:  "",(cJagEllerDu) player," lser ", (the) x1, ".";
           }
  Look:    switch(n)
           {   1: print " (p ", (the) x1, ")";
               2: print " (i ", (the) x1, ")";
               3: print " (som ", (object) x1, ")";
               4: print "^P ", (the) x1;
                  WriteListFrom(child(x1),
                    ENGLISH_BIT+RECURSE_BIT+PARTINV_BIT+TERSE_BIT+CONCEAL_BIT+ISARE_BIT);
                  ".";
               5,6:
                   if (x1 ~= location) {
                       if (x1 has supporter) print "^P "; else print "^I ";
                       print (the) x1, " kan ", (JagEllerDu) player;
                   }
                   else print "^",(cJagEllerDu) player," kan";
                   if (n==5) print " ocks";
                   print " se ";
                   WriteListFrom(child(x1),
                     ENGLISH_BIT+RECURSE_BIT+PARTINV_BIT+TERSE_BIT+CONCEAL_BIT+WORKFLAG_BIT);
                   if (x1 ~= location) ".";
                   " hr.";
               7:  "",(cJagEllerDu) player," ser inget srskilt i den riktningen.";
           }
  LookUnder: switch(n)
           {   1: "Men det r ju mrkt.";
               2: "",(cJagEllerDu) player," hittar inget av intresse.";
           }
  Mild:           "Precis vad jag tnkte.";
  Miscellany:
           switch(n)
           {   1: "(tar bara hnsyn till de frsta sexton fremlen)^";
               2: "Inget att gra!";
               3: print " ",(cJagEllerDu) player," har dtt ";
               4: print " ",(cJagEllerDu) player," har vunnit ";
               5: print "^Vill du BRJA OM, HMTA ett sparat spel";
                  #IFDEF DEATH_MENTION_UNDO;
                  print ", NGRA ditt senaste drag";
                  #ENDIF;
                  if (TASKS_PROVIDED==0)
                      print ", visa FULL information om dina pong";
                  if (deadflag==2 && AMUSING_PROVIDED==0)
                      print ", se ngra frslag p ROLIGA saker att prova";
                  " eller SLUTA?";
               6: "[Din speltolk har tyvrr inte ~ngra~.]";
               7: "~ngra~ misslyckades.  [Det r inte alla speltolkar som har ~ngra~.]";
               8: "Skriv ett av svaren ovan.";
               9: "^Nu r det kolsvart hr inne!";
              10: "Urskta?";
              11: "[Du kan inte ~ngra~ ngot som du inte har gjort!]";
              12: "[Du kan tyvrr inte ~ngra~ tv gnger i rad.]";
              13: "[Senaste draget ngrat.]";
              14: "Tyvrr, det kan inte rttas till.";
              15: "Det var s lite s.";
              16: "~Hoppsan~ kan bara rtta till ett enda ord.";
              17: "Det r kolsvart, och ",(JagEllerDu) player," kan inte se ngonting alls.";
              18: print (string) YOURSELF__TX;
              19: "Lika snygg som alltid.";
              20: "Fr att upprepa ett kommando som ~groda, hoppa~, skriv bara
                   ~igen~, inte ~groda, igen~.";
              21: "Det verkar inte rimligt att gra det igen.";
              22: "Du kan inte brja en mening med ett komma.";
              23: "Du verkar vilja prata med ngon, men jag frstr inte vem.";
              24: "",(cJagEllerDu) player," kan inte prata med ", (the) x1, ".";
              25: "Fr att prata med ngon, prova ~ngon, hej~ eller ngot liknande.";
              26: "(tar frst upp ", (the) not_holding, ")";
              27: "Den meningen frstod jag inte.";
              28: print "Jag tror jag frstod ~";
              29: "Det talet frstod jag inte.";
              30: "Ngon sdan ser ",(JagEllerDu) player," inte till.";
              31: "Du verkar ha sagt fr lite!";
              32: print_ret (CDenEllerHonom) x1, " hller ",(JagEllerDu) player," inte i!"; ! # Could be rephrased to include the correct Den/Det, using ThatorThose?
              33: "Du kan inte anvnda flera freml med det verbet.";
              34: "Du kan bara anvnda flera freml en gng per rad.";
              35: "Jag r inte sker p vad ~", (address) pronoun_word,
                  "~ refererar till.";
              36: "Du undantog ngot som nd inte var med!";
              37: "Det kan du bara gra med ngot levande.";
              38: "Det verbet knner jag inte igen.";
              39: "Det r inte ngot du har ngon anvndning av i det hr spelet.";
              40: "",(cJagEllerDu) player," kan inte se ~", (address) pronoun_word,
                  "~ (", (the) pronoun_obj, ") just nu.";
              41: "Jag frstod inte riktigt den avslutningen.";
              42: print "Det finns ";
                  if (x1==0) print "inga";
                  else { print "bara "; LanguageNumber(x1, 0, multiple_object-->1); }
                  if (x1==1) {
                    if(multiple_object-->1 has neuter)
                      " sdant tillgngligt.";
                    " sdan tillgnglig.";
                  } else
                    " sdana tillgngliga."; ! # Tries to care about gender
              43: "Inget att gra!";
              44: switch(action_to_be) {
                    ##Drop, ##Insert, ##PutOn: "",(JagEllerDu) player," har inget att slppa!";
                    default: "Det finns inget att ta!";
                  }
              45: print "Vem menar du, ";
              46: print "Menar du ";
              47: "Tyvrr kan du bara ange ett freml hr. Exakt vilket menar du?";
              48: print "Jag antar att du menar ~"; ! # This message should work now
                  if (actor~=player) print (name) actor, ", ";
                  PrintCommand();
                  style bold;
                  print " ngon";
                  style roman;
                  print "~, men vem?^";
              49: print "Jag antar att du menar ~";
                  if (actor~=player) print (the) actor, ", ";
                  PrintCommand();
                  style bold;
                  print " ngot";
                  style roman;
                  print "~, men vad?^";
              50: print (JagEllerDu) player," ";
                  if (x1 > 0) print "fick"; else { x1 = -x1; print "frlorade"; }
                  print " just ";
                  LanguageNumber(x1,false,false,neuter);
                  print " pong";
              51: "(Eftersom ngot dramatiskt har hnt
                   har din sekvens av kommandon avbrutits.)";
              52: "^Skriv ett tal mellan 1 och ", x1,
                  ", 0 fr att visa det hr igen eller tryck RETURN.";
              53: "^[Tryck MELLANSLAG.]";
              54: "[Kommentar sparad.]";
              55: "[Kommentar INTE sparad.]";
              56: "~, men sedan tappade du bort mig.";
              57: print "?^";
           }
  NotifyOn,
  NotifyOff: rfalse;
  Objects: switch(n)
           {   1: "Freml ",(JagEllerDu) player," har anvnt:^";
               2: "Inga.";
               3: print "   (",(indefadjworn) x1,")"; ! # Is x1 actually set to the object# in question here? (It is now)
               4: print "   (",(indefadjheld) x1,")"; ! # Is x1 actually set to the object# in question here? (It is now)
               5: print "   (",(indefadjgiven) x1,")"; ! # Is x1 actually set to the object# in question here? (It is now)
               6: print "   (i ", (name) x1, ")";
               7: print "   (i ", (the) x1, ")";
               8: print "   (inuti ", (the) x1, ")";
               9: print "   (p ", (the) x1, ")";
              10: print "   (borta)";
           }
  Open:    switch(n)
           {   1: print_ret (CDenEllerHan) x1,
                  " kan inte ppnas.";
               2: print_ret (CDenEllerHan) x1," verkar ",(indefadjlocked) x1,".";
               3: print_ret (CDenEllerHan) x1," r redan ",(indefadjopen) x1,".";
               4: print (cJagEllerDu) player," ppnar ", (the) x1, " och finner d ";
                  if (WriteListFrom(child(x1),
                      ENGLISH_BIT + TERSE_BIT + CONCEAL_BIT)==0) "ingenting.";
                  ".";
               5: print (cJagEllerDu) player; " ppnar ", (the) x1, ".";
           }
  Order:          print_ret (The) x1," har viktigare saker fr sig.";
  Places: switch (n) {
        1:  print "",(JagEllerDu) player," har beskt: ";
        2:  print ".^";
    }
  Pray:           "Inget direkt uppenbart hnder.";
  Pronouns: switch(n)
           {   1: print "Fr tillfllet refererar ";
               2: print "till ";
               3: print "inte till ngot srskilt";
               4: "inga pronomen till ngot alls.";
               5: ".";
           }
  Pull, Push, Turn:
           switch(n)
           {   1: print_ret (CDenEllerHan) x1, " sitter fast.";
               2: "Det misslyckas.";
               3: "Inget verkar hnda.";
               4: "Det vore direkt ohyfsat.";
           }
  PushDir: switch(n)
           {   1: "Var det det bsta du kunde komma p?";
               2: "Det r ingen riktning.";
               3: "I den riktningen gr det i alla fall inte.";
           }
  PutOn:   switch(n)
           {   1: "",(cJagEllerDu) player," mste hlla i ", (the) x1,
                  " innan ",(JagEllerDu) player," kan lgga ", (DenEllerHonom) x1,
                  " p ngot annat.";
               2: "",(cJagEllerDu) player," kan inte lgga ngot p sig sjlvt.";
               3: "Att lgga saker p ", (the) x1, " skulle inte leda ngon vart.";
               4: "",(cJagEllerDu) player," r inte smidig nog.";
               5: "(tar frst av ", (DenEllerHonom) x1, ")^";
               6: "Det finns inte plats fr ngot mer p ", (the) x1, ".";
               7: "Gjort.";
               8: "",(cJagEllerDu) player," placerar ", (the) x1, " p ", (the) second, ".";
           }
  Quit:    switch(n)
           {   1: print "Svara ja eller nej.";
               2: print "r du sker p att du vill sluta? ";
           }
  Remove:  switch(n)
           {   1: print_ret (CDenEllerHan) x1, " r tyvrr in",(indefadjclosed) x1, ".";
               2: print_ret "Men ",(DenEllerHan) x1, " r inte dr nu.";
               3: "Borttagen.";
           }
  Restart,
  Restore: rfalse;
  Rub:            "Det ger inget anvndbart resultat.";
  Save:    rfalse;
  Score:   switch (n) {
               1: if (deadflag) print "I det spelet fick du ";
                  else print "Du har hittills ftt ihop ";
                  print score, " pong av ", MAX_SCORE,
                  " mjliga p ", turns, " drag";
                  return;
               2: "Det finns inga pong i detta spel.";
           }
  ScriptOn,
  ScriptOff: rfalse;
  Search:  switch(n)
           {   1: "Men det r ju mrkt.";
               2: "Det finns inget p ", (the) x1, ".";
               3: print "P ", (the) x1;
                  WriteListFrom(child(x1),
                      TERSE_BIT + ENGLISH_BIT + ISARE_BIT + CONCEAL_BIT);
                  ".";
               4: "",(cJagEllerDu) player," hittar inget av intresse.";
               5: "",(cJagEllerDu) player," ser inte vad som finns i ", (the) x1, ", eftersom ",
                  (DenEllerHan) x1, " r ",(indefadjclosed) x1,".";
               6: print_ret (The) x1, " r ",(indefadjempty) x1,".";
               7: print "I ", (the) x1;
                  WriteListFrom(child(x1),
                      TERSE_BIT + ENGLISH_BIT + ISARE_BIT + CONCEAL_BIT);
                  ".";
           }
  Set:            "Nej, ",(JagEllerDu) player," kan inte stta ", (DenEllerHonom) x1, ".";
  SetTo:          "Nej, ",(JagEllerDu) player," kan inte stta ", (DenEllerHonom) x1, " till ngot.";
  Show:    switch(n)
           {   1: "",(cJagEllerDu) player," hller inte i ", (the) x1, ".";
               2: print (The) x1, " r inte imponera";
                  if (x1 has pluralname) "de.";
                  if (x1 has neuter) "t."; else "d.";
           }
  Sing:           print_ret (cMinEllerDin) player, " sngrst r inte mycket att hurra fr.";
  Sleep:          "",(cJagEllerDu) player," knner ",(MigEllerDig) player," inte direkt smnig.";
  Smell:          "",(cJagEllerDu) player," knner inga ovntade lukter.";
  Sorry:          "Det r okej. Fr den hr gngen.";
  Squeeze: switch(n)
           {   1: "Tafsa inte!";
               2: "Det ger inget mrkbart resultat.";
           }
  Strong:         "Riktiga ventyrare anvnder inte sdana ord.";
  Swim:           "Det finns inte s mycket vatten att simma i.";
  Swing:          "Det finns just inget vettigt att gunga hr.";
  SwitchOn: switch(n)
           {   1: print_ret (CDenEllerHan) x1," verkar inte vara ngot ",(JagEllerDu) player," kan sl av och p.";
               2: print_ret (CDenEllerHan) x1,
                  " r redan p.";
               3: "",(cJagEllerDu) player," slr p ", (the) x1, ".";
           }
  SwitchOff: switch(n)
           {   1: print_ret (CDenEllerHan) x1," verkar inte vara ngot ",(JagEllerDu) player," kan sl av och p.";
               2: print_ret (CDenEllerHan) x1, " r redan av.";
               3: "",(cJagEllerDu) player," slr av ", (the) x1, ".";
           }
  Take:    switch(n)
           {   1: print "Tag";
                  if(noun has pluralname) "na.";
                  if(noun has neuter) "et."; else "en.";
               2: "",(cJagEllerDu) player," r alltid sjlvupptagen.";
               3: "Det vill ",(DenEllerHan) x1," nog inte.";
               4: print_ret "D hade ",(JagEllerDu) player," frst behvt lmna ",(the) x1, ".";
               5: "",(cJagEllerDu) player," har redan ", (DenEllerHonom) x1, ".";
               6: print_ret (CDenEllerHan) noun, " verkar tillhra ", (the) x1, ".";
               7: print_ret (CDenEllerHan) noun, " verkar vara en del av ", (the) x1, ".";
               8: print_ret (cJagEllerDu) player," kan inte komma t ",(DenEllerHonom) x1, "."; ! # This must be modified to handle neuter correctly
               9: print_ret (The) x1, " r inte ",(indefadjopen) x1, ".";
              10: print_ret (cJagEllerDu)player," kan knappast flytta ", (DenEllerHonom) x1, ".";
              11: print_ret (CDenEllerHan) x1, " sitter fast.";
              12: "",(cJagEllerDu) player," br redan p fr mycket.";
              13: "(lgger ", (the) x1, " i ", (the) SACK_OBJECT,
                  " fr att f plats)";
           }
  Taste:          "",(cJagEllerDu) player," knner ingen ovntad smak.";
  Tell:    switch(n)
           {   1: "",(cJagEllerDu) player," pratar lite med dig sjlv.";
               2: "Ingen reaktion.";
           }
  Think:          "En utmrkt id!";
  ThrowAt: switch(n)
           {   1: "Meningslst.";
               2: "Nr det vl kommer till kritan vgar ",(JagEllerDu) player," inte.";
           }
  Touch:   switch(n)
           {   1: "Bort med tassarna!";
               2: "Det knns ungefr som ",(JagEllerDu) player," hade frvntat ",(MigEllerDig) player,".";
               3: "Om du tror att det hjlper, s visst.";
           }
  TranscribeOn,
  TranscribeOff,
  TranscribeShow: rfalse;
  Unlock:  switch(n)
           {   1: print_ret (CDenEllerHan) x1, " verkar inte vara ngot ",(JagEllerDu) player," kan lsa upp.";
               2: print_ret (CDenEllerHan) x1, " r redan o",(indefadjlocked) x1,".";
               3: print_ret (CDenEllerHan) x1, " verkar inte passa lset.";
               4: "",(cJagEllerDu) player," lser upp ", (the) x1, ".";
           }
  VagueGo: rfalse;
  Verify:  rfalse;
  Wait:           "",(cJagEllerDu) player," vntar.";
  Wake:           "Den grymma sanningen r att det hr inte r ngon drm.";
  WakeOther:      "Det verkar ondigt.";
  Wave:    switch(n)
           {   1: "Men ",(JagEllerDu) player," hller inte i ", (DenEllerHonom) x1, ".";
               2: "",(cJagEllerDu) player," ser fnig ut nr ",(JagEllerDu) player," viftar med ", (the) x1, ".";
           }
  WaveHands:      "",(cJagEllerDu) player," vinkar, ven om det knns lite fnigt.";
  Wear:    switch(n)
           {   1: "",(cJagEllerDu) player," kan inte ta p ", (MigEllerDig) player, " ", (DenEllerHonom) x1, "!";
               2: "",(cJagEllerDu) player," hller inte i ", (DenEllerHonom) x1, "!";
               3: print_ret (CDenEllerHonom) x1, " har ",(JagEllerDu) player," redan p ",(MigEllerDig) player,"!";
               4: "",(cJagEllerDu) player," tar p ", (MigEllerDig) player, " ", (the) x1, ".";
           }
  Yes, No:        "Det var en retorisk frga.";
  ];

#Endif; ! ifndef STRIKT_IMPERFEKT
#Ifndef STRIKT_PRESENS;

[ PastMsg n x1;
  Prompt:  print "^>";
  Answer, Ask:    "",(cJagEllerDu) player, " fick inget svar.";
  Attack:         "Vld var knappast lsningen hr.";
  Blow:           "Det tycktes vara meningslst att blsa p ", (DenEllerHonom) x1, ".";
  Burn:           "Det tycktes vara farligt och fga produktivt.";
  Buy:            "Det fanns just inget att kpa.";
  Climb:          "Det verkade inte s konstruktivt.";
  Close:   switch(n)
           {   1: print_ret (CDenEllerHan) x1," var inte ngot ",(JagEllerDu) player," kunde stnga.";
               2: print_ret (CDenEllerHan) x1,
                  " var redan ",(indefadjclosed) x1,".";
               3: "",(cJagEllerDu) player, " stngde ", (the) x1, ".";
           }
  CommandsOff,
  CommandsOn,
  CommandsRead:
    rfalse;
  Consult:        "",(cJagEllerDu) player," upptckte inget intressant i ", (the) x1, ".";
  Cut:            print "Att skra i ";
                  if(x1 == player) print "sig sjlv";
                  else print(the) x1;
                  " verkade inte srskilt konstruktivt.";
  Dig:            "Det skulle antagligen inte ge s mycket att grva dr.";
  Disrobe: switch(n)
           {   1: print_ret (CDenEllerHonom) x1, " hade ", (JagEllerDu) player, " inte p ",(MigEllerDig) player,".";
               2: "",(cJagEllerDu) player," tog av ", (the) x1, ".";
           }
  Drink:          "Det fanns inget vrt att dricka dr.";
  Drop:    switch(n)
           {   1: print_ret (CDenEllerHan) x1, " var redan dr.";
               2: "",(cJagEllerDu) player," hade inte ", (DenEllerHonom) x1, ".";
               3: "(",(cJagEllerDu) player ," tog frst av ", (the) x1, ")";
               4: "Slppt.";
           }
  Eat:     switch(n)
           {   1: print (CDenEllerHan) x1," var helt enkelt otlig";
                  if(x1 has pluralname) "a.";
                  if(x1 has neuter) "t."; else ".";
               2: "",(cJagEllerDu) player," t ", (the) x1, ". Det var inte illa.";
           }
  EmptyT:  switch(n)
           {   1: print_ret (The) x1, " kunde inte innehlla saker.";
               2: print_ret (The) x1, " var ",(indefadjclosed) x1,".";
               3: print_ret (The) x1, " var redan ",(indefadjempty) x1,".";
               4: "Det skulle just inte ha tmt ngonting alls.";
           }
  Enter:   switch(n)
           {   1: print "Men ",(JagEllerDu) player," var ju redan ";
                  if (x1 has supporter) print "p "; else print "i ";
                  print_ret (the) x1, ".";
               2: print (CDenEllerHan) x1, " var inte till fr "; ! # Should be more varied.
                  switch (verb_word) {
                      'st','stll': "att st p.";
                      'sitt': "att sitta p.";
                      'ligg': "att ligga p.";
                      default: "det.";
                  }
               3: print_ret (The) x1, " var ",(indefadjclosed) x1,", s det skulle ha varit svrt.";

               4: "Frst hade ",(JagEllerDu) player," behvt stlla ",(MigEllerDig) player," p ",(MinEllerDinGenus) pluralname," egna ftter igen.";

               5: switch (verb_word)
                  {
                      'st','stll':
                        print (cJagEllerDu) player," stllde ", (MigEllerDig) player;
                      'sitt','stt':
                        print (cJagEllerDu) player," satte ", (MigEllerDig) player;
                      'ligg','lgg':
                        print (cJagEllerDu) player," la ", (MigEllerDig) player, "ner";
                      default:
                        print (cJagEllerDu) player," klev ";
                        if(x1 has supporter) print "upp"; else print "in";
                  }
                  if (x1 has supporter) print " p "; else print " i ";
                  print_ret (the) x1, ".";
               6: "(",(cJagEllerDu) player," lmnade ",(the) x1, ")";
               7: if (x1 has supporter) "(klev p ", (the) x1, ")^";
                  if (x1 has container) "(klev in i ", (the) x1, ")^";
                  "(gick p ", (the) x1, ")^";
           }
  Examine: switch(n)
           {   1: "Mrker, substantiv. En frnvaro av ljus att se i.";
               2: "",(cJagEllerDu) player," sg inget speciellt med ", (the) x1, ".";
               3: print (The) x1, " var just nu ";
                  if (x1 has on) "p."; else "av.";
           }
  Exit:    switch(n)
           {   1: "Men ",(JagEllerDu) player," var ju inte i ngot fr tillfllet.";
               2: "Det skulle ha blivit svrt att genomfra, eftersom ", (the) x1, " var ",(indefadjclosed) x1,".";
               3: "",(cJagEllerDu) player," lmnade ",(the) x1, ".";
               4: print "Men ",(JagEllerDu) player," var inte ";
                  if (x1 has supporter) print "p "; else print "i ";
                  print_ret (the) x1, ".";
           }
  Fill:           "Men det fanns inget vatten dr att fylla p.";
  FullScore: switch(n)
           {   1: if (deadflag) print "",(cJagEllerDu) player," fick ";
                  else          print "",(cJagEllerDu) player," hade ";
                  "pong, frdelat enligt fljande:^";
               2: "hittade viktiga freml";
               3: "beskta viktiga platser";
               4: print "totalt (av ", MAX_SCORE; ")";
           }
  GetOff:         "Men ",(JagEllerDu) player," var ju inte p ", (the) x1, " fr tillfllet.";
  Give:    switch(n)
           {   1: "",(cJagEllerDu) player," hll inte i ", (the) x1, ".";
               2: "",(cJagEllerDu) player," bollade lite med ", (the) x1,
                  ", men det gav inte s mycket.";
               3: print_ret (The) x1, " verkade inte bry sig om ",(MinEllerDinGenus) neuter," erbjudande.";
           }
  Go:      switch(n)
           {   1: print "Frst hade ",(JagEllerDu) player," behvt kliva ";
                  if (x1 has supporter) print "av "; else print "ur ";
                  print_ret (the) x1, ".";
               2: print_ret (string) CANTGO__TX;
                ! "You can't go that way."
               3: "",(cJagEllerDu) player," kunde inte klttra upp p ", (the) x1, ".";
               4: "",(cJagEllerDu) player," kunde inte klttra ner p ", (the) x1, ".";
               5: "Det skulle ha blivit svrt, eftersom ", (the) x1, " var i vgen.";
               6: "Det kunde ",(JagEllerDu) player," inte, eftersom ", (the) x1," inte ledde ngonstans.";
           }
  Insert:  switch(n)
           {   1: "",(cJagEllerDu) player," hade behvt hlla i ", (the) x1,
                  " innan ",(DenEllerHan) player," kunde lgga ", (DenEllerHonom) x1,
                  " i ngot annat.";
               2: print_ret (CDenEllerHan) x1, " kunde inte innehlla saker.";
               3: print_ret (The) x1, " var ",(indefadjclosed) x1,".";
               4: "Frst hade ",(JagEllerDu) player," behvt ta av ", (DenEllerHonom) x1, ".";
               5: "",(cJagEllerDu) player," kunde inte lgga ngot i sig sjlvt.";
               6: "(",(cJagEllerDu) player, " tog frst av ", (DenEllerHonom) x1, ")^";
               7: "Det fanns inte plats fr ngot mer i ", (the) x1, ".";
               8: "Gjort.";
               9: "",(cJagEllerDu) player," placerade ", (the) x1, " i ", (the) second, ".";
           }
  Inv:     switch(n)
           {   1: "",(cJagEllerDu) player," hade ingenting.";
               2: print (cJagEllerDu) player," hade";
               3: print ":^";
               4: print ".^";
           }
  Jump:           "",(cJagEllerDu) player," hoppade p stllet. Det gav inget.";
  JumpOver, Tie:  "Det skulle inte ha varit till ngon strre hjlp.";
  Kiss:           "Tnk lite mer p spelet istllet.";
  Listen:         "",(cJagEllerDu) player," hrde inget ovntat.";
  ListMiscellany:
           switch(n)
           {   1: print " (lyste)";
               2: print " (",(indefadjclosed) x1,")";
               3: print " (som var ",(indefadjclosed) x1," och lyste)";
               4: print " (",(indefadjempty) x1,")";
               5: print " (som var ",(indefadjempty) x1," och lyste)";
               6: print " (som var ",(indefadjclosed) x1," och ",(indefadjempty) x1,")";
               7: print " (som var ",(indefadjclosed) x1,", ",(indefadjempty) x1," och lyste)";
               8: print " (som lyste och var ",(indefadjworn) x1;
               9: print " (lyste";
              10: print " (",(indefadjworn) x1;
              11: print " (som ";
              12: print "var ", (indefadjopen) x1;
              13: print "var ", (indefadjopen) x1," men ",(indefadjempty) x1;
              14: print "var ", (indefadjclosed) x1;
              15: print "var ", (indefadjclosed) x1," och ",(indefadjlocked) x1;
              16: print " och ",(indefadjempty) x1;
              17: print " (som var ",(indefadjempty) x1,")";
              18: print " innehllandes ";
              19: print " (p ";
              20: print ", ovanp ";
              21: print " (i ";
              22: print ", inuti ";
           }
  LMode1,
  LMode2,
  LMode3: rfalse;
  Lock:    switch(n)
           {   1: print_ret (CDenEllerHan) x1, " verkade inte vara ngot som ",(JagEllerDu) player," kunde lsa.";
               2: print_ret (CDenEllerHan) x1, " var redan ",(indefadjlocked) x1,".";
               3: "Frst hade ",(JagEllerDu) player," behvt stnga ", (the) x1, ".";
               4: print_ret (CDenEllerHan) x1, " verkade inte passa lset.";
               5:  "",(cJagEllerDu) player," lste ", (the) x1, ".";
           }
  Look:    switch(n)
           {   1: print " (p ", (the) x1, ")";
               2: print " (i ", (the) x1, ")";
               3: print " (som ", (object) x1, ")";
               4: print "^P ", (the) x1;
                  WriteListFrom(child(x1),
                    ENGLISH_BIT+RECURSE_BIT+PARTINV_BIT+TERSE_BIT+CONCEAL_BIT+ISARE_BIT);
                  ".";
               5,6:
                   if (x1 ~= location) {
                       if (x1 has supporter) print "^P "; else print "^I ";
                       print (the) x1, " kunde ", (JagEllerDu) player;
                   }
                   else print "^",(cJagEllerDu) player," kunde";
                   if (n==5) print " ocks";
                   print " se ";
                   WriteListFrom(child(x1),
                     ENGLISH_BIT+RECURSE_BIT+PARTINV_BIT+TERSE_BIT+CONCEAL_BIT+WORKFLAG_BIT);
                   if (x1 ~= location) ".";
                   " dr.";
               7:  "",(cJagEllerDu) player," sg inget srskilt i den riktningen.";
           }
  LookUnder: switch(n)
           {   1: "Men det var ju mrkt.";
               2: "",(JagEllerDu) player," hittade inget av intresse.";
           }
  Mild:           "Precis vad jag tnkte.";
  Miscellany:
           switch(n)
           {   1: "(tog bara hnsyn till de frsta sexton fremlen)^";
               2: "Inget fanns att gra!";
               3: print " ",(cJagEllerDu) player," har dtt ";
               4: print " ",(cJagEllerDu) player," har vunnit ";
               5: print "^Vill du BRJA OM, HMTA ett sparat spel";
                  #IFDEF DEATH_MENTION_UNDO;
                  print ", NGRA ditt senaste drag";
                  #ENDIF;
                  if (TASKS_PROVIDED==0)
                      print ", visa FULL information om dina pong";
                  if (deadflag==2 && AMUSING_PROVIDED==0)
                      print ", se ngra frslag p ROLIGA saker att prova";
                  " eller SLUTA?";
               6: "[Din speltolk har tyvrr inte ~ngra~.]";
               7: "~ngra~ misslyckades.  [Det r inte alla speltolkar som har ~ngra~.]";
               8: "Skriv ett av svaren ovan.";
               9: "^Det blev kolsvart dr inne!";
              10: "Urskta?";
              11: "[Du kan inte ~ngra~ ngot som du inte hade gjort!]";
              12: "[Du kan tyvrr inte ~ngra~ tv gnger i rad.]";
              13: "[Senaste draget ngrat.]";
              14: "Tyvrr, det kan inte rttas till.";
              15: "Det var s lite s.";
              16: "~Hoppsan~ kan bara rtta till ett enda ord.";
              17: "Det var kolsvart, och ",(JagEllerDu) player," kunde inte se ngonting alls.";
              18: print (string) YOURSELF__TX;
              19: "", (cJagEllerDu) actor, " var lika snygg som alltid.";
              20: "Fr att upprepa ett kommando som ~groda, hoppa~, skriv bara
                   ~igen~, inte ~groda, igen~.";
              21: "Det verkade inte rimligt att gra det igen.";
              22: "Du kan inte brja en mening med ett komma.";
              23: "Du verkar vilja prata med ngon, men jag frstr inte vem.";
              24: "",(cJagEllerDu) player," kunde inte prata med ", (the) x1, ".";
              25: "Fr att prata med ngon, prova ~ngon, hej~ eller ngot liknande.";
              26: "(tog frst upp ", (the) not_holding, ")";
              27: "Den meningen frstod jag inte.";
              28: print "Jag trodde jag frstod ~";
              29: "Det talet frstod jag inte.";
              30: "Ngon sdan sg ",(JagEllerDu) player," inte till.";
              31: "Du verkar ha sagt fr lite!";
              32: print_ret (CDenEllerHonom) x1, " hll ",(JagEllerDu) player," inte i!"; ! # Could be rephrased to include the correct Den/Det, using ThatorThose?
              33: "Du kan inte anvnda flera freml med det verbet.";
              34: "Du kan bara anvnda flera freml en gng per rad.";
              35: "Jag var inte sker p vad ~", (address) pronoun_word,
                  "~ refererar till.";
              36: "Du undantog ngot som nd inte var med!";
              37: "Det kan du bara gra med ngot levande.";
              38: "Det verbet knner jag inte igen.";
              39: "Det var inte ngot du har ngon anvndning av i det hr spelet.";
              40: "",(cJagEllerDu) player," kunde inte se ~", (address) pronoun_word,
                  "~ (", (the) pronoun_obj, ") just d.";
              41: "Jag frstod inte riktigt den avslutningen.";
              42: print "Det fanns ";
                  if (x1==0) print "inga";
                  else { print "bara "; LanguageNumber(x1, 0, multiple_object-->1); }
                  if (x1==1) {
                    if(multiple_object-->1 has neuter)
                      " sdant tillgngligt.";
                    " sdan tillgnglig.";
                  } else
                    " sdana tillgngliga."; ! # Tries to care about gender
              43: "Inget att gra!";
              44: switch(action_to_be) {
                    ##Drop, ##Insert, ##PutOn: "",(cJagEllerDu) player," har inget att slppa!";
                    default: "Det fanns inget att ta!";
                  }
              45: print "Vem menar du, ";
              46: print "Menar du ";
              47: "Tyvrr kan du bara ange ett freml hr. Exakt vilket menar du?";
              48: print "Jag antar att du menar ~"; ! # This message should work now
                  if (actor~=player) print (name) actor, ", ";
                  PrintCommand();
                  style bold;
                  print " ngon";
                  style roman;
                  print "~, men vem?^";
              49: print "Jag antog att du menar ~";
                  if (actor~=player) print (the) actor, ", ";
                  PrintCommand();
                  style bold;
                  print " ngot";
                  style roman;
                  print "~, men vad?^";
              50: print (cJagEllerDu) player," ";
                  if (x1 > 0) print "fick"; else { x1 = -x1; print "frlorade"; }
                  print " just d ";
                  LanguageNumber(x1,false,false,neuter);
                  print " pong";
              51: "(Eftersom ngot dramatiskt har hnt
                   har din sekvens av kommandon avbrutits.)";
              52: "^Skriv ett tal mellan 1 och ", x1,
                  ", 0 fr att visa det hr igen eller tryck RETURN.";
              53: "^[Tryck MELLANSLAG.]";
              54: "[Kommentar sparad.]";
              55: "[Kommentar INTE sparad.]";
              56: "~, men sedan tappade ",(JagEllerDu) player," bort mig.";
              57: print "?^";
           }
  NotifyOn,
  NotifyOff:
    rfalse;
  Objects: switch(n)
           {   1: "Freml ",(JagEllerDu) player," hade anvnt:^";
               2: "Inga.";
               3: print "   (",(indefadjworn) x1,")"; ! # Is x1 actually set to the object# in question here? (It is now)
               4: print "   (",(indefadjheld) x1,")"; ! # Is x1 actually set to the object# in question here? (It is now)
               5: print "   (",(indefadjgiven) x1,")"; ! # Is x1 actually set to the object# in question here? (It is now)
               6: print "   (i ", (name) x1, ")";
               7: print "   (i ", (the) x1, ")";
               8: print "   (inuti ", (the) x1, ")";
               9: print "   (p ", (the) x1, ")";
              10: print "   (borta)";
           }
  Open:    switch(n)
           {   1: print_ret (CDenEllerHan) x1,
                  " kunde inte ppnas.";
               2: print_ret (CDenEllerHan) x1," verkade ",(indefadjlocked) x1,".";
               3: print_ret (CDenEllerHan) x1," var redan ",(indefadjopen) x1,".";
               4: print (cJagEllerDu) player," ppnade ", (the) x1, " och fann d ";
                  if (WriteListFrom(child(x1),
                      ENGLISH_BIT + TERSE_BIT + CONCEAL_BIT)==0) "ingenting.";
                  ".";
               5: print (cJagEllerDu) player; " ppnade ", (the) x1, ".";
           }
  Order:          print_ret (The) x1," hade viktigare saker fr sig.";
  Places: switch (n) {
        1:  print "",(JagEllerDu) player," hade beskt: ";
        2:  print ".^";
    }
  Pray:           "Inget direkt uppenbart hnde.";
  Pronouns: switch(n)
           {   1: print "Fr tillfllet refererade ";
               2: print "till ";
               3: print "inte till ngot srskilt";
               4: "inga pronomen till ngot alls.";
               5: ".";
           }
  Pull, Push, Turn:
           switch(n)
           {   1: print_ret (CDenEllerHan) x1, " satt fast.";
               2: "Det misslyckades.";
               3: "Inget verkade hnda.";
               4: "Det verkade direkt ohyfsat att gra.";
           }
  PushDir: switch(n)
           {   1: "Var det det bsta du kunde komma p?";
               2: "Det var ingen riktning.";
               3: "I den riktningen gick det i alla fall inte.";
           }
  PutOn:   switch(n)
           {   1: "" ,(cJagEllerDu) player," hade frst behvt hlla i ", (the) x1,
                  " innan ",(JagEllerDu) player," kunde lgga ", (DenEllerHonom) x1,
                  " p ngot annat.";
               2: "",(cJagEllerDu) player," kunde inte lgga ngot p sig sjlvt.";
               3: "Att lgga saker p ", (the) x1, " skulle inte leda ngon vart.";
               4: "",(cJagEllerDu) player," var inte smidig nog.";
               5: "(tog frst av ", (DenEllerHonom) x1, ")^";
               6: "Det fanns inte plats fr ngot mer p ", (the) x1, ".";
               7: "Gjort.";
               8: "",(cJagEllerDu) player," placerade ", (the) x1, " p ", (the) second, ".";
           }
  Quit:    switch(n)
           {   1: print "Svara ja eller nej.";
               2: print "r du sker p att du vill sluta? ";
           }
  Remove:  switch(n)
           {   1: print_ret (CDenEllerHan) x1, " var tyvrr in",(indefadjclosed) x1, ".";
               2: print_ret "Men ",(DenEllerHan) x1, " var inte dr d.";
               3: "Borttagen.";
           }
  Restart,
  Restore: rfalse;
  Rub:            "Det gav inget anvndbart resultat.";
  Save:    rfalse;
  Score:   switch (n) {
               1: if (deadflag) print "I det spelet fick du ";
                  else print "Du har hittills ftt ihop ";
                  print score, " pong av ", MAX_SCORE,
                  " mjliga p ", turns, " drag";
                  return;
               2: "Det finns inga pong i detta spel.";
           }
  ScriptOn,
  ScriptOff: rfalse;
  Search:  switch(n)
           {   1: "Men det var ju mrkt.";
               2: "Det fanns inget p ", (the) x1, ".";
               3: print "P ", (the) x1;
                  WriteListFrom(child(x1),
                      TERSE_BIT + ENGLISH_BIT + ISARE_BIT + CONCEAL_BIT);
                  ".";
               4: "",(cJagEllerDu) player," hittade inget av intresse.";
               5: "",(cJagEllerDu) player," sg inte vad som fanns i ", (the) x1, ", eftersom ",
                  (DenEllerHan) x1, " var ",(indefadjclosed) x1,".";
               6: print_ret (The) x1, " var ",(indefadjempty) x1,".";
               7: print "I ", (the) x1;
                  WriteListFrom(child(x1),
                      TERSE_BIT + ENGLISH_BIT + ISARE_BIT + CONCEAL_BIT);
                  ".";
           }
  Set:            "Nej, ",(JagEllerDu) player," kunde inte stta ", (DenEllerHonom) x1, ".";
  SetTo:          "Nej, ",(JagEllerDu) player," kunde inte stta ", (DenEllerHonom) x1, " till ngot.";
  Show:    switch(n)
           {   1: "",(cJagEllerDu) player," hll inte i ", (the) x1, ".";
               2: print (The) x1, " blev inte imponera";
                  if (x1 has pluralname) "de.";
                  if (x1 has neuter) "t."; else "d.";
           }
  Sing:           print_ret (cMinEllerDin) player, " sngrst var inte mycket att hurra fr.";
  Sleep:          "",(cJagEllerDu) player," knde ",(MigEllerDig) player," inte direkt smnig.";
  Smell:          "",(cJagEllerDu) player," knde inga ovntade lukter.";
  Sorry:          "Det verkade vara okej. Fr den dr gngen.";
  Squeeze: switch(n)
           {   1: "Tafsa inte!";
               2: "Det gav inget mrkbart resultat.";
           }
  Strong:         "Riktiga ventyrare anvnde inte sdana ord.";
  Swim:           "Det fanns inte s mycket vatten att simma i.";
  Swing:          "Det fanns just inget vettigt att gunga dr.";
  SwitchOn: switch(n)
           {   1: print_ret (CDenEllerHan) x1," verkade inte vara ngot ",(JagEllerDu) player," kunde sl av och p.";
               2: print_ret (CDenEllerHan) x1,
                  " var redan p.";
               3: "",(cJagEllerDu) player," slog p ", (the) x1, ".";
           }
  SwitchOff: switch(n)
           {   1: print_ret (CDenEllerHan) x1," verkade inte vara ngot ",(JagEllerDu) player," kunde sl av och p.";
               2: print_ret (CDenEllerHan) x1,
                  " var redan av.";
               3: "",(cJagEllerDu) player," slog av ", (the) x1, ".";
           }
  Take:    switch(n)
           {   1: print "Tag";
                  if(noun has pluralname) "na.";
                  if(noun has neuter) "et."; else "en.";
               2: "",(cJagEllerDu) player," var alltid sjlvupptagen.";
               3: "Det ville ",(DenEllerHan) x1," nog inte.";
               4: print_ret "Frst hade ",(JagEllerDu) player," behvt lmna ",(the) x1, ".";
               5: "",(cJagEllerDu) player," hade redan ", (DenEllerHonom) x1, ".";
               6: print_ret (CDenEllerHan) noun, " verkade tillhra ", (the) x1, ".";
               7: print_ret (CDenEllerHan) noun, " verkade vara en del av ", (the) x1, ".";
               8: print_ret (cJagEllerDu) player," kunde inte komma t ",(DenEllerHonom) x1, ".";

               9: print_ret (The) x1, " var inte ",(indefadjopen) x1, ".";
              10: print_ret (cJagEllerDu) player," kunde knappast flytta ", (DenEllerHonom) x1, ".";
              11: print_ret (CDenEllerHan) x1, " satt fast.";
              12: "",(cJagEllerDu) player," bar redan p fr mycket.";
              13: "(",(cJagEllerDu) player," lade ", (the) x1, " i ", (the) SACK_OBJECT,
                  " fr att f plats)";
           }
  Taste:          "",(cJagEllerDu) player," knde ingen ovntad smak.";
  Tell:    switch(n)
           {   1: "",(cJagEllerDu) player," pratade lite med ",(MigEllerDig) player," sjlv.";
               2: "Det gav ingen reaktion.";
           }
  Think:          "Det var en utmrkt id!";
  ThrowAt: switch(n)
           {   1: "Det var meningslst.";
               2: "Nr det vl kom till kritan vgade ",(JagEllerDu) player," inte.";
           }
  Touch:   switch(n)
           {   1: "Bort med tassarna!";
               2: "Det kndes ungefr som ",(JagEllerDu) player," hade frvntat ",(MigEllerDig) player,".";
               3: "Om du tror att det hjlper, s visst.";
           }
  TranscribeOn,
  TranscribeOff,
  TranscribeShow: rfalse;
  Unlock:  switch(n)
           {   1: print_ret (CDenEllerHan) x1, " verkade inte vara ngot ",(JagEllerDu) player," kunde lsa upp.";
               2: print_ret (CDenEllerHan) x1," var redan o",(indefadjlocked) x1,".";
               3: print_ret (CDenEllerHan) x1, " verkade inte passa lset.";
               4: "",(cJagEllerDu) player," lste upp ", (the) x1, ".";
           }
  VagueGo: rfalse;
  Verify:  rfalse;
  Wait:           "",(cJagEllerDu) player," vntade.";
  Wake:           "Den grymma sanningen var att det hr inte var ngon drm.";
  WakeOther:      "Det verkade ondigt.";
  Wave:    switch(n)
           {   1: "Men ",(JagEllerDu) player," hll inte i ", (DenEllerHonom) x1, ".";
               2: "",(cJagEllerDu) player," sg fnig ut nr ",(JagEllerDu) player," viftade med ", (the) x1, ".";
           }
  WaveHands:      "",(cJagEllerDu) player," vinkade, ven om det kndes lite fnigt.";
  Wear:    switch(n)
           {   1: "",(cJagEllerDu) player," kunde inte ta p ", (MigEllerDig) player, " ", (DenEllerHonom) x1, "!";
               2: "",(cJagEllerDu) player," hll inte i ", (DenEllerHonom) x1, "!";
               3: print_ret (CDenEllerHonom) x1, " hade ",(JagEllerDu) player," redan p ",(MigEllerDig) player, "!";
               4: "",(cJagEllerDu) player," tog p ", (MigEllerDig) player, " ", (the) x1, ".";
           }
  Yes, No:        "Det var en retorisk frga.";
  ];

#Endif; ! ifndef STRIKT_PRESENS

